@@ -9,7 +9,6 @@ use Carp qw/croak/;
 use Cwd;
 use Class::MOP;
 use String::RewritePrefix;
-use List::MoreUtils qw/ any /;
 
 use namespace::clean;
 
@@ -155,24 +154,21 @@ sub class2tempdir {
     return $tmpdir->stringify;
 }
 
-=head2 dist_indicator_file_list
-
-Returns a list of files which can be tested to check if you're inside a checkout
-
-=cut
-
-sub dist_indicator_file_list {
-    qw/ Makefile.PL Build.PL dist.init /;
-}
-
 =head2 home($class)
 
 Returns home directory for given class.
 
-Note that the class must be loaded for the home directory to be found using this function.
+=head2 dist_indicator_file_list
+
+Returns a list of files which can be tested to check if you're inside
+a checkout
 
 =cut
 
+sub dist_indicator_file_list {
+    qw{Makefile.PL Build.PL dist.ini};
+}
+
 sub home {
     my $class = shift;
 
@@ -185,8 +181,25 @@ sub home {
 
             # find the @INC entry in which $file was found
             (my $path = $inc_entry) =~ s/$file$//;
-            my $home = find_home_unloaded_in_checkout($path);
-            return $home if $home;
+            $path ||= cwd() if !defined $path || !length $path;
+            my $home = dir($path)->absolute->cleanup;
+
+            # pop off /lib and /blib if they're there
+            $home = $home->parent while $home =~ /b?lib$/;
+
+            # only return the dir if it has a Makefile.PL or Build.PL or dist.ini
+            if (grep { -f $home->file($_) } dist_indicator_file_list()) {
+                # clean up relative path:
+                # MyApp/script/.. -> MyApp
+
+                my $dir;
+                my @dir_list = $home->dir_list();
+                while (($dir = pop(@dir_list)) && $dir eq '..') {
+                    $home = dir($home)->parent->parent;
+                }
+
+                return $home->stringify;
+            }
         }
 
         {
@@ -205,42 +218,6 @@ sub home {
     return 0;
 }
 
-=head2 find_home_unloaded_in_checkout ($path)
-
-Tries to determine if C<$path> (or cwd if not supplied)
-looks like a checkout. Any leading lib or blib components
-will be removed, then the directory produced will be checked
-for the existance of a C<< dist_indicator_file_list() >>.
-
-If one is found, the directory will be returned, otherwise false.
-
-=cut
-
-sub find_home_unloaded_in_checkout {
-    my ($path) = @_;
-    $path ||= cwd() if !defined $path || !length $path;
-    my $home = dir($path)->absolute->cleanup;
-
-    # pop off /lib and /blib if they're there
-    $home = $home->parent while $home =~ /b?lib$/;
-
-    # only return the dir if it has a Makefile.PL or Build.PL or dist.ini
-    if (any { $_ } map { -f $home->file($_) } dist_indicator_file_list()) {
-
-        # clean up relative path:
-        # MyApp/script/.. -> MyApp
-
-        my $dir;
-        my @dir_list = $home->dir_list();
-        while (($dir = pop(@dir_list)) && $dir eq '..') {
-            $home = dir($home)->parent->parent;
-        }
-
-        return $home->stringify;
-    }
-
-}
-
 =head2 prefix($class, $name);
 
 Returns a prefixed action.
